@@ -59,6 +59,25 @@ def _check():
         elif "GTA02" in cpuinfo: # N9
             print("* Neo FreeRunner GTA02 detected")
             return "neo"
+
+    # check lsb_release
+    try:
+        proc = subprocess.Popen(['lsb_release', '-s', '-i'],
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE)
+        distributionId = proc.communicate()[0].decode("utf-8").lower().strip()
+        print(distributionId)
+        # import pdb; pdb.set_trace()
+        if distributionId == 'mer':
+            # TODO: could be ale Nemo mobile or other Mer based distro,
+            # we should probably discern those two in the future
+            print("* Jolla (or other Mer based device) detected")
+            return "jolla"
+    except:
+        e = sys.exc_info()[1]
+        print("platform detection: running lsb_release failed")
+        print(e)
+
     return None
 
 
